ovsdpdk
==========================================

1.0.0 - 2015.2 - Liberty

#### Table of Contents

1. [Overview - what is networking-ovs-dpdk module ?](#overview)
2. [Installation - how to install ovs with dpdk ?](#installation)
3. [Uninstallation - how to uninstall ovs with dpdk ?](#uninstallation)
4. [Support - what platforms are supported ?](#support)


Overview
--------

The ovsdpdk module is responsible for installation of openvswitch with DPDK support.
As of now we are not providing package distributions.
Current procedure is to replace vanilla ovs binaries with dpdk tuned binaries build from SRC code.


Installation
------------

#### Installing ovsdpdk puppet module

Please refer to getstarted docs available in networking-ovs-dpdk/doc/source/getstarted/puppet/

Uninstallation
--------------

[ToDo - currently not automated]


Support
-------

Supported platforms:
* Ubuntu 14.04 LTS

